@@ -2,4 +2,4 @@ from client import SocketClient, SimpleClient
 from server import SocketDaemon
 from controller import SocketController
 from connection import Connection
-from websocket import WebSocketDaemon
\ No newline at end of file
+from websocket import WebSocketDaemon, WebSocketProxy, startwebsocketproxy
\ No newline at end of file
